Coverage for tests/test_dunder_main.py: 100%

# Coverage for tests/test_dunder_main.py : 100%

## 8 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import os

2

3

4 import pytest

5 from shopyo import __main__

6

7

8

9

10 def test_dunder_main(monkeypatch, capfd):

11 monkeypatch.setattr("sys.argv", [""])

12 __main__.main()

13 captured = capfd.readouterr()

14 assert "No arguments supplied" in captured.out